#[repr(transparent)]pub struct OutSel(pub u32);Expand description
Trigger Source IN0 to IN15 selector
Tuple Fields
0: u32Implementations
Sourceimpl OutSel
impl OutSel
Sourcepub const fn set_in0_seln(&mut self, val: u8)
pub const fn set_in0_seln(&mut self, val: u8)
Selects digital glitch detector as a trigger source.
Sourcepub const fn set_in1_seln(&mut self, val: u8)
pub const fn set_in1_seln(&mut self, val: u8)
Selects TDET event as a trigger source.
Sourcepub const fn set_in2_seln(&mut self, val: u8)
pub const fn set_in2_seln(&mut self, val: u8)
Selects Code Watchdog 0 event as a trigger source.
Sourcepub const fn in4_seln(&self) -> u8
pub const fn in4_seln(&self) -> u8
Selects low-voltage event on VDD_CORE rail as a trigger source.
Sourcepub const fn set_in4_seln(&mut self, val: u8)
pub const fn set_in4_seln(&mut self, val: u8)
Selects low-voltage event on VDD_CORE rail as a trigger source.
Sourcepub const fn set_in5_seln(&mut self, val: u8)
pub const fn set_in5_seln(&mut self, val: u8)
Selects Watchdog 0 timer event as a trigger source.
Sourcepub const fn set_in6_seln(&mut self, val: u8)
pub const fn set_in6_seln(&mut self, val: u8)
Selects Flash ECC mismatch event as a trigger source.
Sourcepub const fn in7_seln(&self) -> u8
pub const fn in7_seln(&self) -> u8
Secure violation interrupt (Memory Block Checker (MBC) interrupt or secure AHB (AHBSC) matrix violation, and SYSCON XEN violation).
Sourcepub const fn set_in7_seln(&mut self, val: u8)
pub const fn set_in7_seln(&mut self, val: u8)
Secure violation interrupt (Memory Block Checker (MBC) interrupt or secure AHB (AHBSC) matrix violation, and SYSCON XEN violation).
Sourcepub const fn in9_seln(&self) -> u8
pub const fn in9_seln(&self) -> u8
SPC VDD_CORE glitch detect and VDD glitch detect (SPC_VDD_CORE_GLITCH_DETECT_SC[GLITCH_DETECT_FLAG] OR SPC_VDD _GLITCH_DETECT_SC[GLITCH_DETECT_FLAG]).
Sourcepub const fn set_in9_seln(&mut self, val: u8)
pub const fn set_in9_seln(&mut self, val: u8)
SPC VDD_CORE glitch detect and VDD glitch detect (SPC_VDD_CORE_GLITCH_DETECT_SC[GLITCH_DETECT_FLAG] OR SPC_VDD _GLITCH_DETECT_SC[GLITCH_DETECT_FLAG]).
Sourcepub const fn set_in10_seln(&mut self, val: u8)
pub const fn set_in10_seln(&mut self, val: u8)
Selects PKC error event as a trigger source.
Sourcepub const fn set_in11_seln(&mut self, val: u8)
pub const fn set_in11_seln(&mut self, val: u8)
Selects Code Watchdog 1 event as a trigger source.
Sourcepub const fn set_in12_seln(&mut self, val: u8)
pub const fn set_in12_seln(&mut self, val: u8)
Selects Watchdog 1 timer event as a trigger source.
Sourcepub const fn in13_seln(&self) -> u8
pub const fn in13_seln(&self) -> u8
Selects FREQME out of range status output as a trigger source.
Sourcepub const fn set_in13_seln(&mut self, val: u8)
pub const fn set_in13_seln(&mut self, val: u8)
Selects FREQME out of range status output as a trigger source.
Sourcepub const fn set_in14_seln(&mut self, val: u8)
pub const fn set_in14_seln(&mut self, val: u8)
Selects software event 0 as a trigger source.
Sourcepub const fn set_in15_seln(&mut self, val: u8)
pub const fn set_in15_seln(&mut self, val: u8)
Selects software event 1 as a trigger source.