nxp-pac

Crates

git

Versions

mcxa577

Flavors

OutSel1

Struct OutSel1 

#[repr(transparent)]
pub struct OutSel1(pub u32);
Trigger Source IN16 to IN31 selector

Tuple Fields

0: u32

Implementations

Source

impl OutSel1

pub const fn in16_seln(&self) -> u8

SPC VDD low voltage detect.

pub const fn set_in16_seln(&mut self, val: u8)

SPC VDD low voltage detect.

pub const fn in18_seln(&self) -> u8

Reserved.

pub const fn set_in18_seln(&mut self, val: u8)

Reserved.

pub const fn in20_seln(&self) -> u8

Selects VDD_MAIN clock tamper output event as a trigger source.

pub const fn set_in20_seln(&mut self, val: u8)

Selects VDD_MAIN clock tamper output event as a trigger source.

pub const fn in25_seln(&self) -> u8

SOCTRIM_ERR to SOCTRIM_ERR OR together.

pub const fn set_in25_seln(&mut self, val: u8)

SOCTRIM_ERR to SOCTRIM_ERR OR together.

pub const fn in27_seln(&self) -> u8

ERM multibit error interrupt.

pub const fn set_in27_seln(&mut self, val: u8)

ERM multibit error interrupt.