#[repr(transparent)]pub struct OutSel1(pub u32);Expand description
Trigger Source IN16 to IN31 selector
Tuple Fields
0: u32Implementations
Sourceimpl OutSel1
impl OutSel1
Sourcepub const fn set_in16_seln(&mut self, val: u8)
pub const fn set_in16_seln(&mut self, val: u8)
SPC VDD low voltage detect.
Sourcepub const fn set_in18_seln(&mut self, val: u8)
pub const fn set_in18_seln(&mut self, val: u8)
Reserved.
Sourcepub const fn in20_seln(&self) -> u8
pub const fn in20_seln(&self) -> u8
Selects VDD_MAIN clock tamper output event as a trigger source.
Sourcepub const fn set_in20_seln(&mut self, val: u8)
pub const fn set_in20_seln(&mut self, val: u8)
Selects VDD_MAIN clock tamper output event as a trigger source.
Sourcepub const fn set_in25_seln(&mut self, val: u8)
pub const fn set_in25_seln(&mut self, val: u8)
SOCTRIM_ERR to SOCTRIM_ERR OR together.
Sourcepub const fn set_in27_seln(&mut self, val: u8)
pub const fn set_in27_seln(&mut self, val: u8)
ERM multibit error interrupt.